@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -25,7 +25,11 @@
 class EqualizerPreset : public PluginPresetBase {
  public:
   EqualizerPreset(PresetType preset_type, const int& index = 0);
-  ~EqualizerPreset();
+  EqualizerPreset(const EqualizerPreset&) = delete;
+  auto operator=(const EqualizerPreset&) -> EqualizerPreset& = delete;
+  EqualizerPreset(const EqualizerPreset&&) = delete;
+  auto operator=(const EqualizerPreset&&) -> EqualizerPreset& = delete;
+  ~EqualizerPreset() override;
 
  private:
   GSettings *input_settings_left = nullptr, *input_settings_right = nullptr, *output_settings_left = nullptr,
