@@ -73,14 +73,20 @@ class PluginBase {
 
   uint rate = 0U;
 
-  float buffer_duration = 0.0F;
-
   bool package_installed = true;
 
   bool bypass = false;
 
   bool connected_to_pw = false;
 
+  bool send_notifications = false;
+
+  float delta_t = 0.0F;
+
+  float notification_time_window = 1.0F / 20.0F;  // seconds
+
+  std::chrono::time_point<std::chrono::system_clock> clock_start;
+
   std::vector<float> dummy_left, dummy_right;
 
   [[nodiscard]] auto get_node_id() const -> uint;
@@ -135,9 +141,6 @@ class PluginBase {
   float input_gain = 1.0F;
   float output_gain = 1.0F;
 
-  float notification_time_window = 1.0F / 20.0F;  // seconds
-  float notification_dt = 0.0F;
-
   std::vector<gulong> gconnections;
 
   void setup_input_output_gain();
