@@ -276,7 +276,11 @@ void application_class_init(ApplicationClass* klass) {
       hide_all_windows(gapp);
 
       g_application_quit(G_APPLICATION(gapp));
-    } else if (g_variant_dict_contains(options, "load-preset") != 0) {
+
+      return EXIT_SUCCESS;
+    }
+
+    if (g_variant_dict_contains(options, "load-preset") != 0) {
       const char* name = nullptr;
 
       if (g_variant_dict_lookup(options, "load-preset", "&s", &name) != 0) {
@@ -286,6 +290,8 @@ void application_class_init(ApplicationClass* klass) {
           } else {
             g_settings_reset(self->settings, "last-used-input-preset");
           }
+
+          return EXIT_SUCCESS;
         }
 
         if (self->presets_manager->preset_file_exists(PresetType::output, name)) {
@@ -294,31 +300,45 @@ void application_class_init(ApplicationClass* klass) {
           } else {
             g_settings_reset(self->settings, "last-used-output-preset");
           }
+
+          return EXIT_SUCCESS;
         }
       }
-    } else if (g_variant_dict_contains(options, "reset") != 0) {
+    }
+
+    if (g_variant_dict_contains(options, "reset") != 0) {
       util::reset_all_keys_except(self->settings);
 
       self->soe->reset_settings();
       self->sie->reset_settings();
 
       util::info("All settings were reset");
-    } else if (g_variant_dict_contains(options, "hide-window") != 0) {
+
+      return EXIT_SUCCESS;
+    }
+
+    if (g_variant_dict_contains(options, "hide-window") != 0) {
       hide_all_windows(gapp);
 
       util::info("Hiding the window...");
-    } else if (g_variant_dict_contains(options, "bypass") != 0) {
+
+      return EXIT_SUCCESS;
+    }
+
+    if (g_variant_dict_contains(options, "bypass") != 0) {
       if (int bypass_arg = 2; g_variant_dict_lookup(options, "bypass", "i", &bypass_arg)) {
         if (bypass_arg == 1) {
           g_settings_set_boolean(self->settings, "bypass", 1);
         } else if (bypass_arg == 2) {
           g_settings_set_boolean(self->settings, "bypass", 0);
         }
+
+        return EXIT_SUCCESS;
       }
-    } else {
-      g_application_activate(gapp);
     }
 
+    g_application_activate(gapp);
+
     return G_APPLICATION_CLASS(application_parent_class)->command_line(gapp, cmdline);
   };
 
@@ -397,19 +417,25 @@ void application_init(Application* self) {
                 },
                 nullptr, nullptr, nullptr};
 
-  entries[2] = {"about",
-                [](GSimpleAction* action, GVariant* parameter, gpointer gapp) {
-                  std::array<const char*, 2> authors = {"Wellington Wallace", nullptr};
+  entries[2] = {
+      "about",
+      [](GSimpleAction* action, GVariant* parameter, gpointer gapp) {
+        std::array<const char*, 4> developers = {"Wellington Wallace <wellingtonwallace@gmail.com>",
+                                                 "Giusy Digital <kurmikon@libero.it>", "Vincent Chernin", nullptr};
 
-                  gtk_show_about_dialog(
-                      gtk_application_get_active_window(GTK_APPLICATION(gapp)), "program-name", APP_NAME, "version",
-                      VERSION, "comments", _("Audio effects for PipeWire applications"), "authors", authors.data(),
-                      "logo-icon-name",
-                      IS_DEVEL_BUILD ? std::string(tags::app::id).append(".Devel").c_str() : tags::app::id,
-                      "license-type", GTK_LICENSE_GPL_3_0, "website", "https://github.com/wwmm/easyeffects",
-                      "system-information", std::string("Commit: ").append(COMMIT_DESC).c_str(), nullptr);
-                },
-                nullptr, nullptr, nullptr};
+        std::array<const char*, 3> documenters = {"Wellington Wallace <wellingtonwallace@gmail.com>",
+                                                  "Giusy Digital <kurmikon@libero.it>", nullptr};
+
+        adw_show_about_window(
+            gtk_application_get_active_window(GTK_APPLICATION(gapp)), "application-name", APP_NAME, "version", VERSION,
+            "developer-name", "Wellington Wallace", "developers", developers.data(), "application-icon",
+            IS_DEVEL_BUILD ? std::string(tags::app::id).append(".Devel").c_str() : tags::app::id, "copyright",
+            "Copyright © 2017–2022 Easy Effects Contributors", "license-type", GTK_LICENSE_GPL_3_0, "website",
+            "https://github.com/wwmm/easyeffects", "debug-info", std::string("Commit: ").append(COMMIT_DESC).c_str(),
+            "translator-credits", _("Weblate https://hosted.weblate.org/projects/easyeffects/"), "documenters",
+            documenters.data(), "issue-url", "https://github.com/wwmm/easyeffects/issues", nullptr);
+      },
+      nullptr, nullptr, nullptr};
 
   entries[3] = {"fullscreen",
                 [](GSimpleAction* action, GVariant* parameter, gpointer gapp) {
