@@ -112,6 +112,8 @@ auto AutoGain::init_ebur128() -> bool {
     return false;
   }
 
+  internal_output_gain = 1.0;
+
   if (ebur_state != nullptr) {
     ebur128_destroy(&ebur_state);
 
@@ -230,7 +232,22 @@ void AutoGain::process(std::span<float>& left_in,
 
   if (EBUR128_SUCCESS != ebur128_loudness_shortterm(ebur_state, &shortterm)) {
     failed = true;
-  } else if (shortterm > 10.0) {
+  }
+
+  if (EBUR128_SUCCESS != ebur128_loudness_global(ebur_state, &global)) {
+    failed = true;
+  }
+
+  if (std::isinf(momentary) || std::isnan(momentary)) {
+    /*
+      Assuming zero so that the output gain is negative. This should avoid undesirably high amplification in case
+      a bad resutla comes from libebur128
+    */
+
+    momentary = 0.0;
+  }
+
+  if (shortterm > 10.0 || std::isinf(shortterm) || std::isnan(shortterm)) {
     /*
       Sometimes when a stream is started right after EasyEffects has been initialized a very large shorterm value is
       calculated. Probably because of some weird high intensity transient. So it is better to ignore unresonable large
@@ -240,9 +257,7 @@ void AutoGain::process(std::span<float>& left_in,
     shortterm = momentary;
   }
 
-  if (EBUR128_SUCCESS != ebur128_loudness_global(ebur_state, &global)) {
-    failed = true;
-  } else if (global > 10.0) {
+  if (global > 10.0 || std::isinf(global) || std::isnan(global)) {
     /*
       Sometimes when a stream is started right after EasyEffects has been initialized a very large integrated value is
       calculated. Probably because of some weird high intensity transient. So it is better to ignore unresonable large
@@ -354,14 +369,10 @@ void AutoGain::process(std::span<float>& left_in,
   if (post_messages) {
     get_peaks(left_in, right_in, left_out, right_out);
 
-    notification_dt += buffer_duration;
-
-    if (notification_dt >= notification_time_window) {
+    if (send_notifications) {
       results.emit(loudness, internal_output_gain, momentary, shortterm, global, relative, range);
 
       notify();
-
-      notification_dt = 0.0F;
     }
   }
 }
