@@ -38,7 +38,7 @@ Compressor::Compressor(const std::string& tag,
   }
 
   gconnections.push_back(g_signal_connect(settings, "changed::sidechain-type",
-                                          G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                                          G_CALLBACK(+[](GSettings* settings, const char* key, gpointer user_data) {
                                             auto self = static_cast<Compressor*>(user_data);
 
                                             self->update_sidechain_links(key);
@@ -46,7 +46,7 @@ Compressor::Compressor(const std::string& tag,
                                           this));
 
   gconnections.push_back(g_signal_connect(settings, "changed::sidechain-input-device",
-                                          G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                                          G_CALLBACK(+[](GSettings* settings, const char* key, gpointer user_data) {
                                             auto self = static_cast<Compressor*>(user_data);
 
                                             self->update_sidechain_links(key);
@@ -186,9 +186,7 @@ void Compressor::process(std::span<float>& left_in,
   if (post_messages) {
     get_peaks(left_in, right_in, left_out, right_out);
 
-    notification_dt += buffer_duration;
-
-    if (notification_dt >= notification_time_window) {
+    if (send_notifications) {
       reduction_port_value = lv2_wrapper->get_control_port_value("rlm");
       sidechain_port_value = lv2_wrapper->get_control_port_value("slm");
       curve_port_value = lv2_wrapper->get_control_port_value("clm");
@@ -200,8 +198,6 @@ void Compressor::process(std::span<float>& left_in,
       envelope.emit(envelope_port_value);
 
       notify();
-
-      notification_dt = 0.0F;
     }
   }
 }
