@@ -103,9 +103,7 @@ void Deesser::process(std::span<float>& left_in,
   if (post_messages) {
     get_peaks(left_in, right_in, left_out, right_out);
 
-    notification_dt += buffer_duration;
-
-    if (notification_dt >= notification_time_window) {
+    if (send_notifications) {
       // values needed as double for levelbars widget ui, so we convert them here
 
       detected_port_value = static_cast<double>(lv2_wrapper->get_control_port_value("detected"));
@@ -115,8 +113,6 @@ void Deesser::process(std::span<float>& left_in,
       compression.emit(compression_port_value);
 
       notify();
-
-      notification_dt = 0.0F;
     }
   }
 }
