@@ -35,11 +35,11 @@ void EchoCancellerPreset::save(nlohmann::json& json) {
 
   json[section][instance_name]["output-gain"] = g_settings_get_double(settings, "output-gain");
 
-  json[section][instance_name]["frame-size"] = g_settings_get_int(settings, "frame-size");
-
   json[section][instance_name]["filter-length"] = g_settings_get_int(settings, "filter-length");
 
   json[section][instance_name]["residual-echo-suppression"] = g_settings_get_int(settings, "residual-echo-suppression");
+
+  json[section][instance_name]["near-end-suppression"] = g_settings_get_int(settings, "near-end-suppression");
 }
 
 void EchoCancellerPreset::load(const nlohmann::json& json) {
@@ -49,10 +49,10 @@ void EchoCancellerPreset::load(const nlohmann::json& json) {
 
   update_key<double>(json.at(section).at(instance_name), settings, "output-gain", "output-gain");
 
-  update_key<int>(json.at(section).at(instance_name), settings, "frame-size", "frame-size");
-
   update_key<int>(json.at(section).at(instance_name), settings, "filter-length", "filter-length");
 
   update_key<int>(json.at(section).at(instance_name), settings, "residual-echo-suppression",
                   "residual-echo-suppression");
+
+  update_key<int>(json.at(section).at(instance_name), settings, "near-end-suppression", "near-end-suppression");
 }
