@@ -51,13 +51,13 @@ struct Data {
 
   uint serial = 0;
 
-  app::Application* application;
+  app::Application* application{};
 
   std::shared_ptr<Equalizer> equalizer;
 
   std::vector<sigc::connection> connections;
 
-  std::vector<gulong> gconnections, gconnections_left, gconnections_right;
+  std::vector<gulong> gconnections;
 };
 
 struct _EqualizerBox {
@@ -73,7 +73,7 @@ struct _EqualizerBox {
 
   GtkStack* stack;
 
-  GtkBox *bands_box_left, *bands_box_right;
+  GtkListView *listview_left, *listview_right;
 
   GtkSpinButton *nbands, *balance, *pitch_left, *pitch_right;
 
@@ -83,6 +83,8 @@ struct _EqualizerBox {
 
   GSettings *settings, *settings_left, *settings_right;
 
+  GtkStringList *string_list_left, *string_list_right;
+
   Data* data;
 };
 
@@ -312,9 +314,9 @@ auto import_apo_preset(EqualizerBox* self, const std::string& file_path) -> bool
   if (bands.empty()) {
     return false;
   }
-  
+
   std::ranges::stable_sort(bands, {}, &APO_Band::freq);
-  
+
   // Apply APO parameters obtained
   g_settings_set_int(self->settings, "num-bands",
                      static_cast<int>(std::min(static_cast<uint>(bands.size()), max_bands)));
@@ -384,7 +386,7 @@ void on_import_apo_preset_clicked(EqualizerBox* self, GtkButton* btn) {
                        // notify error on preset loading
                        ui::show_fixed_toast(
                            self->toast_overlay,
-                           _("APO Preset Not Loaded. File Format May Be Wrong. Please Check Its Content."));
+                           _("APO Preset Not Loaded. File Format May Be Not Supported. Please Check Its Content."));
                      }
 
                      g_free(path);
@@ -475,7 +477,7 @@ auto parse_graphiceq_config(const std::string& str, std::vector<struct GraphicEQ
     bands_substr = band_match.suffix().str();
   }
 
-  return (bands.size() > 0U);
+  return !bands.empty();
 }
 
 auto import_graphiceq_preset(EqualizerBox* self, const std::string& file_path) -> bool {
@@ -506,7 +508,7 @@ auto import_graphiceq_preset(EqualizerBox* self, const std::string& file_path) -
   if (bands.empty()) {
     return false;
   }
-  
+
   std::ranges::stable_sort(bands, {}, &GraphicEQ_Band::freq);
 
   // Apply GraphicEQ parameters obtained
@@ -561,28 +563,29 @@ void on_import_geq_preset_clicked(EqualizerBox* self, GtkButton* btn) {
 
   gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter);
 
-  g_signal_connect(dialog, "response", G_CALLBACK(+[](GtkNativeDialog* dialog, int response, EqualizerBox* self) {
-                     if (response != GTK_RESPONSE_ACCEPT) {
-                       g_object_unref(dialog);
-                       return;
-                     }
+  g_signal_connect(
+      dialog, "response", G_CALLBACK(+[](GtkNativeDialog* dialog, int response, EqualizerBox* self) {
+        if (response != GTK_RESPONSE_ACCEPT) {
+          g_object_unref(dialog);
+          return;
+        }
 
-                     auto* chooser = GTK_FILE_CHOOSER(dialog);
-                     auto* file = gtk_file_chooser_get_file(chooser);
-                     auto* path = g_file_get_path(file);
+        auto* chooser = GTK_FILE_CHOOSER(dialog);
+        auto* file = gtk_file_chooser_get_file(chooser);
+        auto* path = g_file_get_path(file);
 
-                     if (!import_graphiceq_preset(self, path)) {
-                       // notify error on preset loading
-                       ui::show_fixed_toast(
-                           self->toast_overlay,
-                           _("GraphicEQ Preset Not Loaded. File Format May Be Wrong. Please Check Its Content."));
-                     }
+        if (!import_graphiceq_preset(self, path)) {
+          // notify error on preset loading
+          ui::show_fixed_toast(
+              self->toast_overlay,
+              _("GraphicEQ Preset Not Loaded. File Format May Be Not Supported. Please Check Its Content."));
+        }
 
-                     g_free(path);
-                     g_object_unref(file);
-                     g_object_unref(dialog);
-                   }),
-                   self);
+        g_free(path);
+        g_object_unref(file);
+        g_object_unref(dialog);
+      }),
+      self);
 
   gtk_native_dialog_set_modal(GTK_NATIVE_DIALOG(dialog), 1);
   gtk_native_dialog_show(GTK_NATIVE_DIALOG(dialog));
@@ -590,63 +593,103 @@ void on_import_geq_preset_clicked(EqualizerBox* self, GtkButton* btn) {
 
 // ### End GraphicEQ Section ###
 
-template <Channel channel>
-void build_channel_bands(EqualizerBox* self, const int& nbands, const bool& split_mode) {
-  GSettings* settings = nullptr;
-  GtkBox* bands_box = nullptr;
+auto sort_bands(EqualizerBox* self, const int nbands, GSettings* settings, const bool& sort_by_freq)
+    -> std::vector<std::string> {
+  std::vector<int> list(nbands);
 
-  if constexpr (channel == Channel::left) {
-    settings = self->settings_left;
+  std::iota(list.begin(), list.end(), 0);
 
-    bands_box = self->bands_box_left;
-  } else if constexpr (channel == Channel::right) {
-    settings = self->settings_right;
+  if (sort_by_freq) {
+    std::ranges::sort(list, [=](const int& a, const int& b) {
+      const auto freq_a = g_settings_get_double(settings, tags::equalizer::band_frequency[a].data());
 
-    bands_box = self->bands_box_right;
+      const auto freq_b = g_settings_get_double(settings, tags::equalizer::band_frequency[b].data());
+
+      return freq_a < freq_b;
+    });
   }
 
+  std::vector<std::string> output;
+
+  output.reserve(nbands);
+
   for (int n = 0; n < nbands; n++) {
-    auto* band_box = ui::equalizer_band_box::create();
-
-    ui::equalizer_band_box::setup(band_box, settings, n);
-
-    gtk_box_append(bands_box, GTK_WIDGET(band_box));
+    output.push_back(util::to_string(list[n]));
   }
+
+  return output;
 }
 
-void build_all_bands(EqualizerBox* self) {
-  for (auto& handler_id : self->data->gconnections_left) {
-    g_signal_handler_disconnect(self->settings_left, handler_id);
-  }
-
-  for (auto& handler_id : self->data->gconnections_right) {
-    g_signal_handler_disconnect(self->settings_right, handler_id);
-  }
-
-  self->data->gconnections_left.clear();
-  self->data->gconnections_right.clear();
-
-  for (auto* band_box_ptr : {self->bands_box_left, self->bands_box_right}) {
-    for (auto* child = gtk_widget_get_first_child(GTK_WIDGET(band_box_ptr)); child != nullptr;) {
-      auto* next_child = gtk_widget_get_next_sibling(child);
-
-      gtk_box_remove(band_box_ptr, child);
-
-      child = next_child;
-    }
-  }
-
+void build_all_bands(EqualizerBox* self, const bool& sort_by_freq) {
   const auto split = g_settings_get_boolean(self->settings, "split-channels") != 0;
 
   const auto nbands = g_settings_get_int(self->settings, "num-bands");
 
-  build_channel_bands<Channel::left>(self, nbands, split);
+  auto list = sort_bands(self, nbands, self->settings_left, sort_by_freq);
+
+  gtk_string_list_splice(self->string_list_left, 0, g_list_model_get_n_items(G_LIST_MODEL(self->string_list_left)),
+                         util::make_gchar_pointer_vector(list).data());
 
   if (split) {
-    build_channel_bands<Channel::right>(self, nbands, split);
+    list = sort_bands(self, nbands, self->settings_right, sort_by_freq);
+
+    gtk_string_list_splice(self->string_list_right, 0, g_list_model_get_n_items(G_LIST_MODEL(self->string_list_right)),
+                           util::make_gchar_pointer_vector(list).data());
   }
 }
 
+void on_sort_bands(EqualizerBox* self, GtkButton* btn) {
+  build_all_bands(self, true);
+}
+
+template <Channel channel>
+void setup_listview(EqualizerBox* self) {
+  auto* factory = gtk_signal_list_item_factory_new();
+
+  // setting the factory callbacks
+
+  g_signal_connect(factory, "setup",
+                   G_CALLBACK(+[](GtkSignalListItemFactory* factory, GtkListItem* item, EqualizerBox* self) {
+                     auto* band_box = ui::equalizer_band_box::create();
+
+                     gtk_list_item_set_activatable(item, 0);
+                     gtk_list_item_set_child(item, GTK_WIDGET(band_box));
+
+                     g_object_set_data(G_OBJECT(item), "band-box", band_box);
+
+                     if constexpr (channel == Channel::left) {
+                       ui::equalizer_band_box::setup(band_box, self->settings_left);
+                     } else if constexpr (channel == Channel::right) {
+                       ui::equalizer_band_box::setup(band_box, self->settings_right);
+                     }
+                   }),
+                   self);
+
+  g_signal_connect(
+      factory, "bind", G_CALLBACK(+[](GtkSignalListItemFactory* factory, GtkListItem* item, EqualizerBox* self) {
+        auto* band_box =
+            static_cast<ui::equalizer_band_box::EqualizerBandBox*>(g_object_get_data(G_OBJECT(item), "band-box"));
+
+        auto* child_item = gtk_list_item_get_item(item);
+        auto* band_id_str = gtk_string_object_get_string(GTK_STRING_OBJECT(child_item));
+
+        int band_id = 0;
+
+        util::str_to_num(band_id_str, band_id);
+
+        ui::equalizer_band_box::bind(band_box, band_id);
+      }),
+      self);
+
+  if constexpr (channel == Channel::left) {
+    gtk_list_view_set_factory(self->listview_left, factory);
+  } else if constexpr (channel == Channel::right) {
+    gtk_list_view_set_factory(self->listview_right, factory);
+  }
+
+  g_object_unref(factory);
+}
+
 void setup(EqualizerBox* self,
            std::shared_ptr<Equalizer> equalizer,
            const std::string& schema_path,
@@ -673,7 +716,10 @@ void setup(EqualizerBox* self,
 
   equalizer->set_post_messages(true);
 
-  build_all_bands(self);
+  setup_listview<Channel::left>(self);
+  setup_listview<Channel::right>(self);
+
+  build_all_bands(self, false);
 
   self->data->connections.push_back(equalizer->input_level.connect([=](const float left, const float right) {
     util::idle_add([=]() {
@@ -717,13 +763,13 @@ void setup(EqualizerBox* self,
 
   self->data->gconnections.push_back(g_signal_connect(
       self->settings, "changed::num-bands",
-      G_CALLBACK(+[](GSettings* settings, char* key, EqualizerBox* self) { build_all_bands(self); }), self));
+      G_CALLBACK(+[](GSettings* settings, char* key, EqualizerBox* self) { build_all_bands(self, false); }), self));
 
   self->data->gconnections.push_back(g_signal_connect(
       self->settings, "changed::split-channels", G_CALLBACK(+[](GSettings* settings, char* key, EqualizerBox* self) {
         gtk_stack_set_visible_child_name(self->stack, "page_left_channel");
 
-        build_all_bands(self);
+        build_all_bands(self, false);
       }),
       self));
 }
@@ -743,18 +789,8 @@ void dispose(GObject* object) {
     g_signal_handler_disconnect(self->settings, handler_id);
   }
 
-  for (auto& handler_id : self->data->gconnections_left) {
-    g_signal_handler_disconnect(self->settings_left, handler_id);
-  }
-
-  for (auto& handler_id : self->data->gconnections_right) {
-    g_signal_handler_disconnect(self->settings_right, handler_id);
-  }
-
   self->data->connections.clear();
   self->data->gconnections.clear();
-  self->data->gconnections_left.clear();
-  self->data->gconnections_right.clear();
 
   g_object_unref(self->settings);
   g_object_unref(self->settings_left);
@@ -797,8 +833,10 @@ void equalizer_box_class_init(EqualizerBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, output_level_right_label);
 
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, stack);
-  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, bands_box_left);
-  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, bands_box_right);
+  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, listview_left);
+  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, listview_right);
+  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, string_list_left);
+  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, string_list_right);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, nbands);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, mode);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, split_channels);
@@ -810,6 +848,7 @@ void equalizer_box_class_init(EqualizerBoxClass* klass) {
 
   gtk_widget_class_bind_template_callback(widget_class, on_flat_response);
   gtk_widget_class_bind_template_callback(widget_class, on_calculate_frequencies);
+  gtk_widget_class_bind_template_callback(widget_class, on_sort_bands);
   gtk_widget_class_bind_template_callback(widget_class, on_import_apo_preset_clicked);
   gtk_widget_class_bind_template_callback(widget_class, on_import_geq_preset_clicked);
 }
