@@ -93,9 +93,7 @@ void Exciter::process(std::span<float>& left_in,
   if (post_messages) {
     get_peaks(left_in, right_in, left_out, right_out);
 
-    notification_dt += buffer_duration;
-
-    if (notification_dt >= notification_time_window) {
+    if (send_notifications) {
       /// harmonics needed as double for levelbar widget ui, so we convert it here
 
       harmonics_port_value = static_cast<double>(lv2_wrapper->get_control_port_value("meter_drive"));
@@ -107,8 +105,6 @@ void Exciter::process(std::span<float>& left_in,
       harmonics.emit(harmonics_port_value);
 
       notify();
-
-      notification_dt = 0.0F;
     }
   }
 }
