@@ -122,9 +122,7 @@ void Maximizer::process(std::span<float>& left_in,
   if (post_messages) {
     get_peaks(left_in, right_in, left_out, right_out);
 
-    notification_dt += buffer_duration;
-
-    if (notification_dt >= notification_time_window) {
+    if (send_notifications) {
       // reduction needed as double for levelbar widget ui, so we convert it here
 
       reduction_port_value = static_cast<double>(lv2_wrapper->get_control_port_value("gr"));
@@ -132,8 +130,6 @@ void Maximizer::process(std::span<float>& left_in,
       reduction.emit(reduction_port_value);
 
       notify();
-
-      notification_dt = 0.0F;
     }
   }
 }
