@@ -142,9 +142,7 @@ void MultibandGate::process(std::span<float>& left_in,
   if (post_messages) {
     get_peaks(left_in, right_in, left_out, right_out);
 
-    notification_dt += buffer_duration;
-
-    if (notification_dt >= notification_time_window) {
+    if (send_notifications) {
       for (uint n = 0U; n < n_bands; n++) {
         const auto nstr = util::to_string(n);
 
@@ -169,8 +167,6 @@ void MultibandGate::process(std::span<float>& left_in,
       gating.emit(gating_array);
 
       notify();
-
-      notification_dt = 0.0F;
     }
   }
 }
