@@ -34,7 +34,6 @@ void on_process(void* userdata, spa_io_position* position) {
   if (rate != d->pb->rate || n_samples != d->pb->n_samples) {
     d->pb->rate = rate;
     d->pb->n_samples = n_samples;
-    d->pb->buffer_duration = static_cast<float>(n_samples) / static_cast<float>(rate);
 
     d->pb->dummy_left.resize(n_samples);
     d->pb->dummy_right.resize(n_samples);
@@ -42,9 +41,17 @@ void on_process(void* userdata, spa_io_position* position) {
     std::ranges::fill(d->pb->dummy_left, 0.0F);
     std::ranges::fill(d->pb->dummy_right, 0.0F);
 
+    d->pb->clock_start = std::chrono::system_clock::now();
+
     d->pb->setup();
   }
 
+  d->pb->delta_t = 0.001F * static_cast<float>(std::chrono::duration_cast<std::chrono::milliseconds>(
+                                                   std::chrono::system_clock::now() - d->pb->clock_start)
+                                                   .count());
+
+  d->pb->send_notifications = d->pb->delta_t >= d->pb->notification_time_window;
+
   // util::warning("processing: " + util::to_string(n_samples));
 
   auto* in_left = static_cast<float*>(pw_filter_get_dsp_buffer(d->in_left, n_samples));
@@ -100,6 +107,12 @@ void on_process(void* userdata, spa_io_position* position) {
       d->pb->process(left_in, right_in, left_out, right_out, l, r);
     }
   }
+
+  if (d->pb->send_notifications) {
+    d->pb->clock_start = std::chrono::system_clock::now();
+
+    d->pb->send_notifications = false;
+  }
 }
 
 const struct pw_filter_events filter_events = {.process = on_process};
@@ -119,7 +132,11 @@ PluginBase::PluginBase(std::string tag,
       enable_probe(enable_probe),
       settings(g_settings_new_with_path(schema.c_str(), schema_path.c_str())),
       pm(pipe_manager) {
+  std::string description;
+
   if (name != "output_level" && name != "spectrum") {
+    description = tags::plugin_name::get_translated()[name];
+
     bypass = g_settings_get_boolean(settings, "bypass") != 0;
 
     gconnections.push_back(g_signal_connect(settings, "changed::bypass",
@@ -129,6 +146,10 @@ PluginBase::PluginBase(std::string tag,
                                               self->bypass = g_settings_get_boolean(settings, "bypass") != 0;
                                             }),
                                             this));
+  } else if (name == "output_level") {
+    description = _("Output Level Meter");
+  } else if (name == "spectrum") {
+    description = _("Spectrum");
   }
 
   pf_data.pb = this;
@@ -142,7 +163,7 @@ PluginBase::PluginBase(std::string tag,
   pw_properties_set(props_filter, PW_KEY_APP_ID, tags::app::id);
   pw_properties_set(props_filter, PW_KEY_NODE_NAME, filter_name.c_str());
   pw_properties_set(props_filter, PW_KEY_NODE_NICK, name.c_str());
-  pw_properties_set(props_filter, PW_KEY_NODE_DESCRIPTION, name.c_str());
+  pw_properties_set(props_filter, PW_KEY_NODE_DESCRIPTION, description.c_str());
   pw_properties_set(props_filter, PW_KEY_MEDIA_TYPE, "Audio");
   pw_properties_set(props_filter, PW_KEY_MEDIA_CATEGORY, "Filter");
   pw_properties_set(props_filter, PW_KEY_MEDIA_ROLE, "DSP");
