@@ -1,20 +1,20 @@
 /*
- *  Copyright © 2017-2022 Wellington Wallace
+ *  Copyright © 2017-2023 Wellington Wallace
  *
- *  This file is part of EasyEffects.
+ *  This file is part of Easy Effects.
  *
- *  EasyEffects is free software: you can redistribute it and/or modify
+ *  Easy Effects is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
- *  EasyEffects is distributed in the hope that it will be useful,
+ *  Easy Effects is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with EasyEffects.  If not, see <https://www.gnu.org/licenses/>.
+ *  along with Easy Effects. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "presets_manager.hpp"
@@ -465,7 +465,16 @@ auto PresetsManager::load_preset_file(const PresetType& preset_type, const std::
           for (const auto& p : json.at("output").at("plugins_order").get<std::vector<std::string>>()) {
             for (const auto& v : tags::plugin_name::list) {
               if (p.starts_with(v)) {
-                plugins.push_back(p);
+                /*
+                  Old format presets do not have the instance id number in the filter names. They are equal to the
+                  base name.
+                */
+
+                if (p != v) {
+                  plugins.push_back(p);
+                } else {
+                  plugins.push_back(p + "#0");
+                }
 
                 break;
               }
@@ -517,7 +526,16 @@ auto PresetsManager::load_preset_file(const PresetType& preset_type, const std::
           for (const auto& p : json.at("input").at("plugins_order").get<std::vector<std::string>>()) {
             for (const auto& v : tags::plugin_name::list) {
               if (p.starts_with(v)) {
-                plugins.push_back(p);
+                /*
+                  Old format presets do not have the instance id number in the filter names. They are equal to the
+                  base name.
+                */
+
+                if (p != v) {
+                  plugins.push_back(p);
+                } else {
+                  plugins.push_back(p + "#0");
+                }
 
                 break;
               }
@@ -852,96 +870,102 @@ void PresetsManager::notify_error(const PresetError& preset_error, const std::st
 
 auto PresetsManager::create_wrapper(const PresetType& preset_type, std::string_view filter_name)
     -> std::optional<std::unique_ptr<PluginPresetBase>> {
+  auto instance_id = tags::plugin_name::get_id(std::string(filter_name));
+
   if (filter_name.starts_with(tags::plugin_name::autogain)) {
-    return std::make_unique<AutoGainPreset>(preset_type);
+    return std::make_unique<AutoGainPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::bass_enhancer)) {
-    return std::make_unique<BassEnhancerPreset>(preset_type);
+    return std::make_unique<BassEnhancerPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::bass_loudness)) {
-    return std::make_unique<BassLoudnessPreset>(preset_type);
+    return std::make_unique<BassLoudnessPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::compressor)) {
-    return std::make_unique<CompressorPreset>(preset_type);
+    return std::make_unique<CompressorPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::convolver)) {
-    return std::make_unique<ConvolverPreset>(preset_type);
+    return std::make_unique<ConvolverPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::crossfeed)) {
-    return std::make_unique<CrossfeedPreset>(preset_type);
+    return std::make_unique<CrossfeedPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::crystalizer)) {
-    return std::make_unique<CrystalizerPreset>(preset_type);
+    return std::make_unique<CrystalizerPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::deesser)) {
-    return std::make_unique<DeesserPreset>(preset_type);
+    return std::make_unique<DeesserPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::delay)) {
-    return std::make_unique<DelayPreset>(preset_type);
+    return std::make_unique<DelayPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::echo_canceller)) {
-    return std::make_unique<EchoCancellerPreset>(preset_type);
+    return std::make_unique<EchoCancellerPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::equalizer)) {
-    return std::make_unique<EqualizerPreset>(preset_type);
+    return std::make_unique<EqualizerPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::exciter)) {
-    return std::make_unique<ExciterPreset>(preset_type);
+    return std::make_unique<ExciterPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::filter)) {
-    return std::make_unique<FilterPreset>(preset_type);
+    return std::make_unique<FilterPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::gate)) {
-    return std::make_unique<GatePreset>(preset_type);
+    return std::make_unique<GatePreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::limiter)) {
-    return std::make_unique<LimiterPreset>(preset_type);
+    return std::make_unique<LimiterPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::loudness)) {
-    return std::make_unique<LoudnessPreset>(preset_type);
+    return std::make_unique<LoudnessPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::maximizer)) {
-    return std::make_unique<MaximizerPreset>(preset_type);
+    return std::make_unique<MaximizerPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::multiband_compressor)) {
-    return std::make_unique<MultibandCompressorPreset>(preset_type);
+    return std::make_unique<MultibandCompressorPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::multiband_gate)) {
-    return std::make_unique<MultibandGatePreset>(preset_type);
+    return std::make_unique<MultibandGatePreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::pitch)) {
-    return std::make_unique<PitchPreset>(preset_type);
+    return std::make_unique<PitchPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::reverb)) {
-    return std::make_unique<ReverbPreset>(preset_type);
+    return std::make_unique<ReverbPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::rnnoise)) {
-    return std::make_unique<RNNoisePreset>(preset_type);
+    return std::make_unique<RNNoisePreset>(preset_type, instance_id);
+  }
+
+  if (filter_name.starts_with(tags::plugin_name::speex)) {
+    return std::make_unique<SpeexPreset>(preset_type, instance_id);
   }
 
   if (filter_name.starts_with(tags::plugin_name::stereo_tools)) {
-    return std::make_unique<StereoToolsPreset>(preset_type);
+    return std::make_unique<StereoToolsPreset>(preset_type, instance_id);
   }
 
   util::warning("The filter name " + std::string(filter_name) + " base name could not be recognized");
