@@ -125,13 +125,9 @@ void StreamInputEffects::on_app_added(const NodeInfo node_info) {
 }
 
 auto StreamInputEffects::apps_want_to_play() -> bool {
-  for (const auto& link : pm->list_links) {
-    if (link.output_node_id == pm->ee_source_node.id) {
-      if (link.state == PW_LINK_STATE_ACTIVE) {
-        return true;
-      }
-    }
-  }
+  return std::ranges::any_of(pm->list_links, [&](const auto& link) {
+    return (link.output_node_id == pm->ee_source_node.id) && (link.state == PW_LINK_STATE_ACTIVE);
+  });
 
   return false;
 }
@@ -267,7 +263,7 @@ void StreamInputEffects::connect_filters(const bool& bypass) {
         continue;
       }
 
-      if (name == tags::plugin_name::echo_canceller) {
+      if (name.starts_with(tags::plugin_name::echo_canceller)) {
         if (plugins[name]->connected_to_pw) {
           for (const auto& link : pm->link_nodes(pm->output_device.id, plugins[name]->get_node_id(), true)) {
             list_proxies.push_back(link);
